/*
 * Copyright (C) 2015 Niek Linnenbank
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CONFIG_ARM_RASPBERRY_SYSTEM_H
#define __CONFIG_ARM_RASPBERRY_SYSTEM_H

#include "Constant.h"
#include <arm/ARMCore.h>
#include <arm/ARMCacheV6.h>
#include <arm/ARMIO.h>
#include <arm/ARMPaging.h>
#include <arm/ARMMap.h>
#include <arm/ARMKernel.h>
#include <arm/ARMProcess.h>
#include <arm/ARMTraps.h>
#include <FreeNOS/API.h>

#endif /* __CONFIG_ARM_RASPBERRY_SYSTEM_H */
